@@ -31,11 +31,16 @@
 #include <dbus/dbus-message-internal.h>
 #include "selinux.h"
 
+#ifndef DBUS_ENABLE_EMBEDDED_TESTS
+#error This file is only relevant for the embedded tests
+#endif
+
 #ifdef DBUS_UNIX
 # include <dbus/dbus-sysdeps-unix.h>
 #endif
 
-#ifdef DBUS_ENABLE_EMBEDDED_TESTS
+static void die (const char *failure) _DBUS_GNUC_NORETURN;
+
 static void
 die (const char *failure)
 {
@@ -51,12 +56,11 @@ check_memleaks (const char *name)
   printf ("%s: checking for memleaks\n", name);
   if (_dbus_get_malloc_blocks_outstanding () != 0)
     {
-      _dbus_warn ("%d dbus_malloc blocks were not freed\n",
+      _dbus_warn ("%d dbus_malloc blocks were not freed",
                   _dbus_get_malloc_blocks_outstanding ());
       die ("memleaks");
     }
 }
-#endif /* DBUS_ENABLE_EMBEDDED_TESTS */
 
 static DBusInitialFDs *initial_fds = NULL;
 
@@ -72,7 +76,7 @@ test_pre_hook (void)
   initial_fds = _dbus_check_fdleaks_enter ();
 }
 
-static char *progname = "";
+static const char *progname = "";
 
 static void
 test_post_hook (void)
@@ -88,14 +92,13 @@ test_post_hook (void)
 int
 main (int argc, char **argv)
 {
-#ifdef DBUS_ENABLE_EMBEDDED_TESTS
   const char *dir;
   const char *only;
   DBusString test_data_dir;
 
   progname = argv[0];
 
-  if (argc > 1)
+  if (argc > 1 && strcmp (argv[1], "--tap") != 0)
     dir = argv[1];
   else
     dir = _dbus_getenv ("DBUS_TEST_DATA");
@@ -190,10 +193,4 @@ main (int argc, char **argv)
 
   
   return 0;
-#else /* DBUS_ENABLE_EMBEDDED_TESTS */
-
-  printf ("Not compiled with test support\n");
-  
-  return 0;
-#endif
 }
