@@ -254,13 +254,16 @@ check_address (const char *address, DBusError *error)
   int len, i;
 
   _dbus_assert (address != NULL);
+  _DBUS_ASSERT_ERROR_IS_CLEAR (error);
 
   if (!dbus_parse_address (address, &entries, &len, error))
     return NULL;              /* not a valid address */
 
   for (i = 0; i < len; i++)
     {
+      dbus_error_free (error);
       transport = _dbus_transport_open (entries[i], error);
+
       if (transport != NULL)
         break;
     }
@@ -410,6 +413,9 @@ _dbus_transport_open (DBusAddressEntry *entry,
           _DBUS_ASSERT_ERROR_IS_SET (&tmp_error);
           goto out;
           break;
+        default:
+          _dbus_assert_not_reached ("invalid transport open result");
+          break;
         }
     }
 
@@ -746,8 +752,17 @@ _dbus_transport_try_to_authenticate (DBusTransport *transport)
             case DBUS_AUTH_STATE_AUTHENTICATED:
               /* leave as maybe_authenticated */
               break;
-            default:
+
+            case DBUS_AUTH_STATE_WAITING_FOR_INPUT:
+            case DBUS_AUTH_STATE_WAITING_FOR_MEMORY:
+            case DBUS_AUTH_STATE_HAVE_BYTES_TO_SEND:
+            case DBUS_AUTH_STATE_NEED_DISCONNECT:
               maybe_authenticated = FALSE;
+              break;
+
+            case DBUS_AUTH_STATE_INVALID:
+            default:
+              _dbus_assert_not_reached ("invalid authentication state");
             }
         }
 
@@ -1029,7 +1044,9 @@ recover_unused_bytes (DBusTransport *transport)
         }
       
       _dbus_message_loader_get_buffer (transport->loader,
-                                       &buffer);
+                                       &buffer,
+                                       NULL,
+                                       NULL);
       
       orig_len = _dbus_string_get_length (buffer);
       
@@ -1061,7 +1078,9 @@ recover_unused_bytes (DBusTransport *transport)
       dbus_bool_t succeeded;
 
       _dbus_message_loader_get_buffer (transport->loader,
-                                       &buffer);
+                                       &buffer,
+                                       NULL,
+                                       NULL);
 
 #ifdef DBUS_ENABLE_VERBOSE_MODE
       orig_len = _dbus_string_get_length (buffer);
